# ursa-python-wrapper

Python wrapper for URSA crypto library

## Dependencies 

Same as parent project [URSA](https://github.com/hyperledger/ursa/blob/master/docs/build-environment.md)


### Supports Python3.*

# Current Implementations 

* BLS signatures 

